@@ -147,7 +147,7 @@ public final class CloudmarkSpamHandler extends SpamHandler {
 
     @Override
     public void handleHam(final int accountId, final String fullname, final String[] mailIDs, final boolean move, final Session session) throws OXException {
-        ConfigurationService configuration = services.getService(ConfigurationService.class);
+    	ConfigurationService configuration = services.getService(ConfigurationService.class);
         String targetHamEmailAddress = configuration.getProperty("com.openexchange.spamhandler.cloudmark.targetHamEmailAddress", "").trim();
 
         MailAccess<?, ?> mailAccess = null;
@@ -177,9 +177,15 @@ public final class CloudmarkSpamHandler extends SpamHandler {
             }
 
             if (move) {
-                String targetSpamFolder = configuration.getProperty("com.openexchange.spamhandler.cloudmark.targetSpamFolder", "1").trim();
+            	String targetSpamFolder = configuration.getProperty("com.openexchange.spamhandler.cloudmark.targetSpamFolder", "1").trim();
                 if (!targetSpamFolder.equals("0")) {
-                    mailAccess.getMessageStorage().moveMessages(fullname, "INBOX", mailIDs, true);
+                    try {
+                        mailAccess.getMessageStorage().moveMessages(fullname, "INBOX", mailIDs, true);
+                    } finally {
+                        if (null != mailAccess) {
+                            mailAccess.close(true);
+                        }
+                    }
                 }
             }
         } finally {
